powered by
Formats training output into a form suitable for forestFloor feature-contribution package.
forestFloor
# S3 method for Rborist ForestFloorExport(arbOut)
an object of type Rborist produced by training.
Rborist
An object of type ForestFloorExport, as specified by the interface for the forestFloor package.
ForestFloorExport
data(iris) rb <- Rborist(iris[-5], iris[5]) ffe <- ForestFloorExport(rb) library(forestFloor) ForestFloor(ffe)
Run the code above in your browser using DataLab