Learn R Programming

Rborist (version 0.1-1)

ForestFloorExport: Exportation Format for Rborist Training Output

Description

Formats training output into a form suitable for forestFloor feature-contribution package.

Usage

"ForestFloorExport"(arbOut)

Arguments

arbOut
an object of type Rborist produced by training.

Value

ForestFloorExport, as specified by the interface for the forestFloor package.

Examples

Run this code
  ## Not run: 
#     data(iris)
#     rb <- Rborist(iris[-5], iris[5])
#     ffe <- ForestFloorExport(rb)
# 
#     library(forestFloor)
#     ForestFloor(ffe)
#   ## End(Not run)

Run the code above in your browser using DataLab